==> haskell-descriptive-0.9.4-39-i686.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-4kTWXhqwOtjKZy3YZ8sbqa
key: descriptive-0.9.4-4kTWXhqwOtjKZy3YZ8sbqa
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 8bac53999b52a7e739014a4bb4abab28
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-4kTWXhqwOtjKZy3YZ8sbqa
depends:
    aeson-1.0.2.1-9juLbWuUPUaFK1txzTGd5H base-4.9.0.0
    bifunctors-5.4.1-Ac6G6TmMVPE36jXOz0jDKq containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.10-HyvEaD9RF3TGwvwmkJHXws
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-47-i686.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-9SO4fvCOpmg5MOZHpsG7zI
key: descriptive-0.9.4-9SO4fvCOpmg5MOZHpsG7zI
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 213c0b971e000acd528da3caab6f6e48
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-9SO4fvCOpmg5MOZHpsG7zI
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY base-4.9.0.0
    bifunctors-5.4.2-89Yr6mDv1GYKyj9AXEUlAj containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
